Learn R Programming

mongolstats (version 0.1.1)

nso_offline_enable: Enable offline mode

Description

When enabled, HTTP requests are prevented and functions that require the network will raise a clear offline error. Cached metadata can still be used if already available via nso_cache_enable().

Usage

nso_offline_enable()

Arguments

Value

Invisibly, TRUE.

Examples

Run this code
# Enable offline mode
nso_offline_enable()

# Check the option was set
getOption("mongolstats.offline")

# Disable to restore normal operation
nso_offline_disable()

Run the code above in your browser using DataLab