Inspects the table metadata to find the time dimension and returns its available period labels (e.g., years or year-months).
Examples
periods <- nso_table_periods("DT_NSO_0300_001V2")
head(periods)
#> [1] "2025" "2024" "2023" "2022" "2021" "2020"
Inspects the table metadata to find the time dimension and returns its available period labels (e.g., years or year-months).
periods <- nso_table_periods("DT_NSO_0300_001V2")
head(periods)
#> [1] "2025" "2024" "2023" "2022" "2021" "2020"