Executes an nso_query and returns a tidy tibble with one column per
dimension and a numeric value column. Use labels to add _en/_mn
columns for each dimension.
Arguments
- x
An
nso_queryobject.- labels
One of "code", "en", "mn", or "both". "none" is accepted as an alias for "code" (matching
nso_data()). Defaults to themongolstats.default_labelsoption, likenso_data().- value_name
Name of the numeric value column in the result (default: "value").
- include_raw
If TRUE, attach the raw PX payload as attribute
px_raw.